@@ -556,6 +556,12 @@ int ACTIVE_TASK::start(bool test) {
         return 0;
     }
 
+    // use special slot for test app
+    //
+    if (wup->project->app_test) {
+        strcpy(slot_dir, "slots/app_test");
+    }
+
     // run it at above idle priority if it
     // - uses coprocs
     // - uses less than one CPU
@@ -691,6 +697,12 @@ int ACTIVE_TASK::start(bool test) {
         exit(0);
     }
 
+    // use special exec path for test app
+    //
+    if (wup->project->app_test) {
+        strcpy(exec_path, gstate.app_test_file.c_str());
+    }
+
 #ifdef _WIN32
     PROCESS_INFORMATION process_info;
     STARTUPINFO startup_info;
@@ -767,7 +779,7 @@ int ACTIVE_TASK::start(bool test) {
                 break;
             } else {
                 last_error = GetLastError();
-                windows_format_error_string(last_error, error_msg, sizeof(error_msg));
+                windows_format_error_string(last_error, error_msg, sizeof(error_msg), exec_path);
                 msg_printf(wup->project, MSG_INTERNAL_ERROR,
                     "Process creation failed: %s - error code %d (0x%x)",
                     error_msg, last_error, last_error
@@ -801,7 +813,7 @@ int ACTIVE_TASK::start(bool test) {
                 break;
             } else {
                 last_error = GetLastError();
-                windows_format_error_string(last_error, error_msg, sizeof(error_msg));
+                windows_format_error_string(last_error, error_msg, sizeof(error_msg), exec_path);
                 msg_printf(wup->project, MSG_INTERNAL_ERROR,
                     "Process creation failed: %s - error code %d (0x%x)",
                     error_msg, last_error, last_error
@@ -897,7 +909,7 @@ int ACTIVE_TASK::start(bool test) {
 
     if (log_flags.task_debug) {
         msg_printf(wup->project, MSG_INFO,
-            "[task] ACTIVE_TASK::start(): forked process: pid %d\n", pid
+            "[task_debug] ACTIVE_TASK::start(): forked process: pid %d\n", pid
         );
     }
 
@@ -1131,7 +1143,7 @@ int ACTIVE_TASK::start(bool test) {
     //
     if (log_flags.task_debug) {
         msg_printf(wup->project, MSG_INFO,
-            "[task] ACTIVE_TASK::start(): forked process: pid %d\n", pid
+            "[task_debug] ACTIVE_TASK::start(): forked process: pid %d\n", pid
         );
     }
 
@@ -1154,14 +1166,16 @@ error:
         gstate.verify_app_version_files(result);
     }
 
+    if (log_flags.task_debug) {
+        msg_printf(wup->project, MSG_INFO,
+            "[task_debug] couldn't start app: %s", buf
+        );
+    }
+
     char err_msg[4096];
     snprintf(err_msg, sizeof(err_msg), "couldn't start app: %.256s", buf);
     gstate.report_result_error(*result, err_msg);
-    if (log_flags.task_debug) {
-        msg_printf(wup->project, MSG_INFO,
-            "[task] couldn't start app: %s", buf
-        );
-    }
+
     set_task_state(PROCESS_COULDNT_START, "start");
     return retval;
 }
