@@ -142,6 +142,7 @@ int APP::parse(XML_PARSER& xp) {
     safe_strcpy(user_friendly_name, "");
     project = NULL;
     non_cpu_intensive = false;
+    sporadic = false;
     while (!xp.get_tag()) {
         if (xp.match_tag("/app")) {
             if (!strlen(user_friendly_name)) {
@@ -152,7 +153,12 @@ int APP::parse(XML_PARSER& xp) {
         if (xp.parse_str("name", name, sizeof(name))) continue;
         if (xp.parse_str("user_friendly_name", user_friendly_name, sizeof(user_friendly_name))) continue;
         if (xp.parse_bool("non_cpu_intensive", non_cpu_intensive)) continue;
+        if (xp.parse_bool("sporadic", sporadic)) continue;
         if (xp.parse_bool("fraction_done_exact", fraction_done_exact)) continue;
+        if (xp.parse_bool("sporadic", sporadic)) {
+            if (sporadic) gstate.have_sporadic_app = true;
+            continue;
+        }
 #ifdef SIM
         if (xp.parse_double("latency_bound", latency_bound)) continue;
         if (xp.parse_double("fpops_est", fpops_est)) continue;
@@ -402,13 +408,13 @@ int FILE_INFO::parse(XML_PARSER& xp) {
             retval = pfxp->parse(xp);
 #ifdef SIM
             delete pfxp;
-            continue;
-#endif
+#else
             if (!retval) {
                 pers_file_xfer = pfxp;
             } else {
                 delete pfxp;
             }
+#endif
             continue;
         }
         if (xp.match_tag("file_xfer")) {
@@ -685,7 +691,7 @@ bool FILE_INFO::had_failure(int& failnum) {
 
 void FILE_INFO::failure_message(string& s) {
     char buf[1024];
-    snprintf(buf, sizeof(buf), 
+    snprintf(buf, sizeof(buf),
         "<file_xfer_error>\n"
         "  <file_name>%s</file_name>\n"
         "  <error_code>%d (%s)</error_code>\n",
@@ -1087,11 +1093,7 @@ void APP_VERSION::check_graphics_exec() {
 int FILE_REF::parse(XML_PARSER& xp) {
     bool temp;
 
-    safe_strcpy(file_name, "");
-    safe_strcpy(open_name, "");
-    main_program = false;
-    copy_file = false;
-    optional = false;
+    clear();
     while (!xp.get_tag()) {
         if (xp.match_tag("/file_ref")) {
             if (strstr(open_name, "..")) return ERR_BAD_FILENAME;
@@ -1349,3 +1351,92 @@ double RUN_MODE::delay() {
         return 0;
     }
 }
+
+int USER_CPID::parse(XML_PARSER& xp) {
+    clear();
+    while (!xp.get_tag()) {
+        if (xp.match_tag("/user_cpid")) {
+            if (!strlen(email_hash) || !strlen(cpid) || !time) {
+                msg_printf(0, MSG_INTERNAL_ERROR, "USER_CPID::parse() failed");
+                return ERR_XML_PARSE;
+            }
+            break;
+        }
+        if (xp.parse_str("email_hash", email_hash, sizeof(email_hash))) continue;
+        if (xp.parse_str("cpid", cpid, sizeof(cpid))) continue;
+        if (xp.parse_double("time", time)) continue;
+    }
+    return 0;
+}
+
+int USER_CPID::write(MIOFILE& out) {
+    out.printf(
+        "   <user_cpid>\n"
+        "      <email_hash>%s</email_hash>\n"
+        "      <cpid>%s</cpid>\n"
+        "      <time>%f</time>\n"
+        "   </user_cpid>\n",
+        email_hash, cpid, time
+    );
+    return 0;
+}
+
+int USER_CPIDS::parse(XML_PARSER& xp) {
+    while (!xp.get_tag()) {
+        if (xp.match_tag("/user_cpids")) {
+            break;
+        }
+        if (xp.match_tag("user_cpid")) {
+            USER_CPID uc;
+            int retval = uc.parse(xp);
+            if (retval) continue;
+            cpids.push_back(uc);
+        }
+    }
+    return 0;
+}
+
+int USER_CPIDS::write(MIOFILE& out) {
+    out.printf("<user_cpids>\n");
+    for (USER_CPID &cpid: cpids) {
+        cpid.write(out);
+    }
+    out.printf("</user_cpids>\n");
+    return 0;
+}
+
+USER_CPID* USER_CPIDS::lookup(const char* email_hash) {
+    for (USER_CPID &cpid: cpids) {
+        if (!strcmp(cpid.email_hash, email_hash)) {
+            return &cpid;
+        }
+    }
+    return NULL;
+}
+
+// if empty, initialize from projects
+// (should get done once, when updating to this client version)
+//
+void USER_CPIDS::init_from_projects() {
+    for (PROJECT *p: gstate.projects) {
+        if (!strlen(p->email_hash) || !strlen(p->cross_project_id) || !p->user_create_time) {
+            continue;
+        }
+        USER_CPID* ucp = lookup(p->email_hash);
+        if (ucp) {
+            if (p->user_create_time < ucp->time) {
+                strcpy(ucp->cpid, p->cross_project_id);
+                ucp->time = p->user_create_time;
+            }
+        } else {
+            USER_CPID uc;
+            strcpy(uc.email_hash, p->email_hash);
+            strcpy(uc.cpid, p->cross_project_id);
+            uc.time = p->user_create_time;
+            cpids.push_back(uc);
+
+        }
+    }
+}
+
+USER_CPIDS user_cpids;
