@@ -346,6 +346,7 @@ void CLIENT_STATE::assign_results_to_projects() {
     //
     for (i=0; i<active_tasks.active_tasks.size(); i++) {
         ACTIVE_TASK *atp = active_tasks.active_tasks[i];
+        if (atp->always_run()) continue;
         if (!atp->runnable()) continue;
         rp = atp->result;
         if (rp->already_selected) continue;
@@ -410,7 +411,6 @@ RESULT* CLIENT_STATE::highest_prio_project_best_result() {
     for (i=0; i<projects.size(); i++) {
         PROJECT* p = projects[i];
         if (!p->next_runnable_result) continue;
-        if (p->non_cpu_intensive) continue;
         if (first || p->sched_priority > best_prio) {
             first = false;
             best_project = p;
@@ -447,7 +447,7 @@ RESULT* first_coproc_result(int rsc_type) {
             //msg_printf(rp->project, MSG_INFO, "not runnable: %s", rp->name);
             continue;
         }
-        if (rp->non_cpu_intensive()) continue;
+        if (rp->always_run()) continue;
         if (rp->already_selected) continue;
         prio = rp->project->sched_priority;
         if (!best) {
@@ -500,7 +500,7 @@ static RESULT* earliest_deadline_result(int rsc_type) {
         if (rp->resource_type() != rsc_type) continue;
         if (rp->already_selected) continue;
         if (!rp->runnable()) continue;
-        if (rp->non_cpu_intensive()) continue;
+        if (rp->always_run()) continue;
         PROJECT* p = rp->project;
 
         // Skip this job if the project's deadline-miss count is zero.
@@ -740,8 +740,7 @@ void CLIENT_STATE::adjust_rec() {
     for (i=0; i<active_tasks.active_tasks.size(); i++) {
         ACTIVE_TASK* atp = active_tasks.active_tasks[i];
         if (atp->scheduler_state != CPU_SCHED_SCHEDULED) continue;
-        PROJECT* p = atp->result->project;
-        if (p->non_cpu_intensive) continue;
+        if (atp->non_cpu_intensive()) continue;
         work_fetch.accumulate_inst_sec(atp, elapsed_time);
     }
 
@@ -883,6 +882,20 @@ void CLIENT_STATE::make_run_list(vector<RESULT*>& run_list) {
 
     proc_rsc.init();
 
+    // if there are sporadic apps,
+    // subtract the resource usage of those that are computing
+    //
+    if (have_sporadic_app) {
+        proc_rsc.ncpus -= sporadic_resources.ncpus_used;
+        for (int rt=1; rt<proc_rsc.pr_coprocs.n_rsc; rt++) {
+            COPROC& cp = proc_rsc.pr_coprocs.coprocs[rt];
+            COPROC& cp2 = sporadic_resources.sr_coprocs.coprocs[rt];
+            for (int j=0; j<cp.count; j++) {
+                cp.usage[j] = cp2.usage[j];
+            }
+        }
+    }
+
     // do round-robin simulation to find what results miss deadline
     //
     rr_simulation("CPU sched");
@@ -1113,7 +1126,7 @@ void CLIENT_STATE::append_unfinished_time_slice(vector<RESULT*> &run_list) {
         atp->overdue_checkpoint = false;
         if (!atp->result->runnable()) continue;
         if (atp->result->uses_gpu() && gpu_suspend_reason) continue;
-        if (atp->result->non_cpu_intensive()) continue;
+        if (atp->result->always_run()) continue;
         if (atp->scheduler_state != CPU_SCHED_SCHEDULED) continue;
         if (finished_time_slice(atp)) continue;
         atp->result->unfinished_time_slice = true;
@@ -1203,6 +1216,9 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
     }
 
     double ram_left = available_ram();
+    if (have_sporadic_app) {
+        ram_left -= sporadic_resources.mem_used;
+    }
     double swap_left = (global_prefs.vm_max_used_frac)*host_info.m_swap;
 
     if (log_flags.mem_usage_debug) {
@@ -1212,11 +1228,11 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
         );
     }
 
-    // schedule non-CPU-intensive tasks,
+    // schedule non-CPU-intensive and sporadic tasks
     //
     for (i=0; i<results.size(); i++) {
         RESULT* rp = results[i];
-        if (rp->non_cpu_intensive() && rp->runnable()) {
+        if (rp->always_run() && rp->runnable()) {
             atp = get_task(rp);
             if (!atp) {
                 msg_printf(rp->project, MSG_INTERNAL_ERROR,
@@ -1293,26 +1309,41 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
         //      until it reaches deadline pressure.
         // So we'll go with 1).
 
-        // skip jobs whose working set is too large to fit in available RAM
+        // skip jobs whose 'expected working set size' (EWSS)
+        // is too large to fit in available RAM.
+        // To compute EWSS, we start with
+        // - if the job has already run, its recent average WSS
+        // - else if other jobs of this app version have run recently,
+        //      the max of their WSSs
+        // - else the WU's rsc_memory_bound
+        // If project->strict_memory_bound is set,
+        // we max the above with wu.rsc_memory_bound.
+        // This is to handle apps (like CPDN) whose WSS is small for a while
+        // and then gets big.
         //
-        double wss = 0;
+        double ewss = 0;
         if (atp) {
             atp->too_large = false;
-            wss = atp->procinfo.working_set_size_smoothed;
+            ewss = atp->procinfo.working_set_size_smoothed;
         } else {
-            wss = rp->avp->max_working_set_size;
+            ewss = rp->avp->max_working_set_size;
         }
-        if (wss == 0) {
-            wss = rp->wup->rsc_memory_bound;
+        if (rp->project->strict_memory_bound) {
+            ewss = std::max(ewss, rp->wup->rsc_memory_bound);
+        } else {
+            if (ewss == 0) {
+                ewss = rp->wup->rsc_memory_bound;
+            }
         }
-        if (wss > ram_left) {
+
+        if (ewss > ram_left) {
             if (atp) {
                 atp->too_large = true;
             }
             if (log_flags.cpu_sched_debug || log_flags.mem_usage_debug) {
                 msg_printf(rp->project, MSG_INFO,
-                    "[cpu_sched_debug] can't run %s: WS too big %.2fMB > %.2fMB",
-                    rp->name,  wss/MEGA, ram_left/MEGA
+                    "[cpu_sched_debug] skipping %s: estimated WSS (%.2fMB) exceeds RAM left (%.2fMB)",
+                    rp->name,  ewss/MEGA, ram_left/MEGA
                 );
             }
             continue;
@@ -1341,7 +1372,7 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
 
         ncpus_used += rp->avp->avg_ncpus;
         atp->next_scheduler_state = CPU_SCHED_SCHEDULED;
-        ram_left -= wss;
+        ram_left -= ewss;
         if (have_max_concurrent) {
             max_concurrent_inc(rp);
         }
@@ -1380,9 +1411,8 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
             );
         }
 #endif
-        int preempt_type = REMOVE_MAYBE_SCHED;
-        switch (atp->next_scheduler_state) {
-        case CPU_SCHED_PREEMPTED:
+        PREEMPT_TYPE preempt_type = REMOVE_MAYBE_SCHED;
+        if (atp->next_scheduler_state == CPU_SCHED_PREEMPTED) {
             switch (atp->task_state()) {
             case PROCESS_EXECUTING:
                 action = true;
@@ -1424,7 +1454,6 @@ bool CLIENT_STATE::enforce_run_list(vector<RESULT*>& run_list) {
                 break;
             }
             atp->scheduler_state = CPU_SCHED_PREEMPTED;
-            break;
         }
         if (atp->result->uses_coprocs() && atp->task_state() == PROCESS_QUIT_PENDING) {
             coproc_quit_pending = true;
@@ -1612,10 +1641,12 @@ ACTIVE_TASK* CLIENT_STATE::get_task(RESULT* rp) {
     ACTIVE_TASK *atp = lookup_active_task_by_result(rp);
     if (!atp) {
         atp = new ACTIVE_TASK;
-        int retval = atp->get_free_slot(rp);
-        if (retval) {
-            delete atp;
-            return NULL;
+        if (!rp->project->app_test) {
+            int retval = atp->get_free_slot(rp);
+            if (retval) {
+                delete atp;
+                return NULL;
+            }
         }
         atp->init(rp);
         active_tasks.active_tasks.push_back(atp);
