@@ -96,6 +96,7 @@ void LOG_FLAGS::show() {
     show_flag(buf, sizeof(buf), sched_op_debug, "sched_op_debug");
     show_flag(buf, sizeof(buf), scrsave_debug, "scrsave_debug");
     show_flag(buf, sizeof(buf), slot_debug, "slot_debug");
+    show_flag(buf, sizeof(buf), sporadic_debug, "sporadic_debug");
     show_flag(buf, sizeof(buf), state_debug, "state_debug");
     show_flag(buf, sizeof(buf), statefile_debug, "statefile_debug");
     show_flag(buf, sizeof(buf), task_debug, "task_debug");
@@ -419,6 +420,10 @@ int CC_CONFIG::parse_options_client(XML_PARSER& xp) {
             ignore_gpu_instance[PROC_TYPE_INTEL_GPU].push_back(n);
             continue;
         }
+        if (xp.parse_int("ignore_apple_dev", n)) {
+            ignore_gpu_instance[PROC_TYPE_APPLE_GPU].push_back(n);
+            continue;
+        }
         if (xp.parse_int("max_event_log_lines", max_event_log_lines)) continue;
         if (xp.parse_int("max_file_xfers", max_file_xfers)) continue;
         if (xp.parse_int("max_file_xfers_per_project", max_file_xfers_per_project)) continue;
