@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2023 University of California
+// Copyright (C) 2024 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -21,6 +21,7 @@
 
 #ifdef __WXMAC__
 #include <Carbon/Carbon.h>
+#include <wx/uilocale.h>
 #include "filesys.h"
 #include "util.h"
 #include "mac_util.h"
@@ -49,6 +50,7 @@
 #include "DlgEventLog.h"
 #include "procinfo.h"
 #include "sg_BoincSimpleFrame.h"
+#include "DlgGenericMessage.h"
 
 
 bool s_bSkipExitConfirmation = false;
@@ -118,6 +120,7 @@ bool CBOINCGUIApp::OnInit() {
     m_iShutdownCoreClient = 0;
     m_iDisplayExitDialog = 1;
     m_iDisplayShutdownConnectedClientDialog = 1;
+    m_iDisplayAnotherInstanceRunningDialog = 1;
 #ifdef __WXMAC__
     m_iHideMenuBarIcon = 0;
 #endif
@@ -200,6 +203,7 @@ bool CBOINCGUIApp::OnInit() {
     m_pConfig->Read(wxT("AutomaticallyShutdownClient"), &m_iShutdownCoreClient, 0L);
     m_pConfig->Read(wxT("DisplayShutdownClientDialog"), &m_iDisplayExitDialog, 1L);
     m_pConfig->Read(wxT("DisplayShutdownConnectedClientDialog"), &m_iDisplayShutdownConnectedClientDialog, 1L);
+    m_pConfig->Read(wxT("DisplayAnotherInstanceRunningDialog"), &m_iDisplayAnotherInstanceRunningDialog, 1L);
 #ifdef __WXMAC__
     m_pConfig->Read(wxT("HideMenuBarIcon"), &m_iHideMenuBarIcon, 0L);
 #endif
@@ -207,12 +211,15 @@ bool CBOINCGUIApp::OnInit() {
     m_pConfig->Read(wxT("LanguageISO"), &m_strISOLanguageCode, wxT(""));
     m_bUseDefaultLocale = false;
     bool bUseDefaultLocaleDefault = false;
-#ifdef __WXMAC__   // wxLocale::GetLanguageInfo(wxLANGUAGE_DEFAULT) does not work on Mac
-    wxLocale *defaultLocale = new wxLocale;
-    defaultLocale->Init(wxLANGUAGE_DEFAULT);
-    wxString defaultLanguageCode = defaultLocale->GetCanonicalName();
+#ifdef __WXMAC__
+    // Because our translations don't use Apple's standard localization
+    // scheme, the Cocoa APIs used by wxLocale for wxLANGUAGE_DEFAULT
+    // always return English as the language for the reasons explained
+    // in https://stackoverflow.com/questions/48136456. The wxLocale
+    // documentation warns us to use wxUILocale::GetSystemLanguage().
+    int systemLanguageCode = wxUILocale::GetSystemLanguage();
+    wxString defaultLanguageCode = wxLocale::GetLanguageCanonicalName(systemLanguageCode);
     bUseDefaultLocaleDefault = m_strISOLanguageCode == defaultLanguageCode;
-    delete defaultLocale;
 #else
     const wxLanguageInfo *defaultLanguageInfo = wxLocale::GetLanguageInfo(wxLANGUAGE_DEFAULT);
     if (defaultLanguageInfo != NULL) {
@@ -296,6 +303,16 @@ bool CBOINCGUIApp::OnInit() {
             iDesiredLanguageCode = pLI->Language;
         }
     }
+
+#ifdef __WXMAC__
+    // wxLocale::Init(wxLANGUAGE_DEFAULT) does not work correctly
+    // on the Mac so we must use wxUILocale::GetSystemLanguage().
+    if (m_bUseDefaultLocale || (iDesiredLanguageCode == wxLANGUAGE_DEFAULT)) {
+        iDesiredLanguageCode = wxUILocale::GetSystemLanguage();
+        m_strISOLanguageCode = wxLocale::GetLanguageCanonicalName(iDesiredLanguageCode);
+    }
+#endif
+
     m_pLocale->Init(iDesiredLanguageCode);
     if (iDesiredLanguageCode == wxLANGUAGE_DEFAULT) {
         m_strISOLanguageCode = m_pLocale->GetCanonicalName();
@@ -447,8 +464,20 @@ bool CBOINCGUIApp::OnInit() {
     // Detect if BOINC Manager is already running, if so, bring it into the
     // foreground and then exit.
     if (DetectDuplicateInstance()) {
-      printf( "Another instance of BOINC Manager already running.\n");
-            return false;
+        if (GetBOINCMGRDisplayAnotherInstanceRunningMessage()) {
+            wxString appName = m_pSkinManager->GetAdvanced()->GetApplicationName();
+            wxString message;
+            message.Printf(_("Another instance of %s is already running."), appName);
+            CDlgGenericMessageParameters params;
+            params.caption = appName;
+            params.message = message;
+            params.button2 = CDlgGenericMessageButton(false);
+            CDlgGenericMessage dlg(NULL, &params);
+            dlg.ShowModal();
+            SetBOINCMGRDisplayAnotherInstanceRunningMessage(!dlg.GetDisableMessageValue());
+            SaveState();
+        }
+        return false;
     }
 
     // Initialize the main document
@@ -628,6 +657,7 @@ void CBOINCGUIApp::SaveState() {
     m_pConfig->Write(wxT("AutomaticallyShutdownClient"), m_iShutdownCoreClient);
     m_pConfig->Write(wxT("DisplayShutdownClientDialog"), m_iDisplayExitDialog);
     m_pConfig->Write(wxT("DisplayShutdownConnectedClientDialog"), m_iDisplayShutdownConnectedClientDialog);
+    m_pConfig->Write(wxT("DisplayAnotherInstanceRunningDialog"), m_iDisplayAnotherInstanceRunningDialog);
 #ifdef __WXMAC__
     m_pConfig->Write(wxT("HideMenuBarIcon"), m_iHideMenuBarIcon);
 #endif
