@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2014 University of California
+// Copyright (C) 2023 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -80,9 +80,9 @@ CDlgExclusiveApps::CDlgExclusiveApps(wxWindow* parent) :
     m_addExclusiveAppButton = new wxButton( exclusiveAppsListStaticBox, ID_ADDEXCLUSIVEAPPBUTTON, _("Add..."), wxDefaultPosition, wxDefaultSize, 0 );
     m_addExclusiveAppButton->SetToolTip( _("Add an application to this list"));
 	exclusiveAppsButtonSizer->Add( m_addExclusiveAppButton, 0, wxRIGHT, 5 );
-    
+
     exclusiveAppsButtonSizer->AddStretchSpacer();
-    
+
     m_removeExclusiveAppButton = new wxButton( exclusiveAppsListStaticBox, ID_REMOVEEXCLUSIVEAPPBUTTON, _("Remove"), wxDefaultPosition, wxDefaultSize, 0 );
     m_removeExclusiveAppButton->SetToolTip( _("Remove an application from this list"));
 	exclusiveAppsButtonSizer->Add( m_removeExclusiveAppButton, 0, wxLEFT, 5 );
@@ -104,9 +104,9 @@ CDlgExclusiveApps::CDlgExclusiveApps(wxWindow* parent) :
     m_addExclusiveGPUAppButton = new wxButton( exclusiveGPUAppsListStaticBox, ID_ADDEXCLUSIVEGPUAPPBUTTON, _("Add..."), wxDefaultPosition, wxDefaultSize, 0 );
     m_addExclusiveGPUAppButton->SetToolTip( _("Add an application to this list"));
 	exclusiveGPUAppsButtonSizer->Add( m_addExclusiveGPUAppButton, 0, wxRIGHT, 5 );
-    
+
     exclusiveGPUAppsButtonSizer->AddStretchSpacer();
-    
+
     m_removeExclusiveGPUAppButton = new wxButton( exclusiveGPUAppsListStaticBox, ID_REMOVEEXCLUSIVEGPUAPPBUTTON, _("Remove"), wxDefaultPosition, wxDefaultSize, 0 );
     m_removeExclusiveGPUAppButton->SetToolTip( _("Remove an application from this list"));
 	exclusiveGPUAppsButtonSizer->Add( m_removeExclusiveGPUAppButton, 0, wxLEFT, 5 );
@@ -127,8 +127,8 @@ CDlgExclusiveApps::CDlgExclusiveApps(wxWindow* parent) :
 
     moreOptionsLinkSizer->Add(
         new wxHyperlinkCtrl(
-            this, wxID_ANY, wxT("http://boinc.berkeley.edu/wiki/Client_configuration"),
-            wxT("http://boinc.berkeley.edu/wiki/Client_configuration"), 
+            this, wxID_ANY, wxT("https://boinc.berkeley.edu/wiki/Client_configuration"),
+            wxT("https://boinc.berkeley.edu/wiki/Client_configuration"),
             wxDefaultPosition, wxDefaultSize, wxHL_DEFAULT_STYLE
         ),
 #ifdef __WXMAC__
@@ -143,18 +143,18 @@ CDlgExclusiveApps::CDlgExclusiveApps(wxWindow* parent) :
     m_panelButtons = new wxPanel( this, wxID_ANY, wxDefaultPosition, wxDefaultSize, 0 );
     wxBoxSizer* buttonSizer = new wxBoxSizer( wxHORIZONTAL );
 
-    m_btnOK = new wxButton( m_panelButtons, wxID_OK, _("Save"), wxDefaultPosition, wxDefaultSize, 0 );
-    m_btnOK->SetToolTip( _("save all values and close the dialog") );
-    
+    m_btnOK = new wxButton( m_panelButtons, wxID_OK, _("&Save"), wxDefaultPosition, wxDefaultSize, 0 );
+    m_btnOK->SetToolTip( _("Save all values and close the dialog") );
+
     buttonSizer->Add( m_btnOK, 0, wxALL, 5 );
 
     m_btnCancel = new wxButton( m_panelButtons, wxID_CANCEL, _("Cancel"), wxDefaultPosition, wxDefaultSize, 0 );
-    m_btnCancel->SetToolTip( _("close the dialog without saving") );
+    m_btnCancel->SetToolTip( _("Close the dialog without saving") );
     m_btnCancel->SetDefault();
 
     buttonSizer->Add( m_btnCancel, 0, wxALL, 5 );
 
-    m_btnHelp = new wxButton( m_panelButtons, ID_HELPBOINC, _("Help"), wxDefaultPosition, wxDefaultSize, 0 );
+    m_btnHelp = new wxButton( m_panelButtons, ID_HELPBOINC, _("&Help"), wxDefaultPosition, wxDefaultSize, 0 );
     m_btnHelp->SetToolTip( _("shows the preferences web page") );
 
     buttonSizer->Add( m_btnHelp, 0, wxALL, 5 );
@@ -386,11 +386,16 @@ void CDlgExclusiveApps::OnRemoveExclusiveApp(wxCommandEvent& ev) {
 
     // The selection indices are returned in random order.
     // We must sort them to ensure deleting the correct items.
+    //
     selections.Sort((sortcomparefunc)&myCompareInts);
     for (int i=numSelected-1; i>=0; --i) {
         m_exclusiveApsListBox->Delete(selections[i]);
         m_bExclusiveAppsDataChanged = true;
     }
+    // Check if no more exclusive apps exist.  If no more, disable remove button.
+    if (!m_exclusiveApsListBox->HasClientObjectData()) {
+        m_removeExclusiveAppButton->Disable();
+    }
     ev.Skip();
 }
 
@@ -400,18 +405,23 @@ void CDlgExclusiveApps::OnRemoveExclusiveGPUApp(wxCommandEvent& ev) {
 
     // The selection indices are returned in random order.
     // We must sort them to ensure deleting the correct items.
+    //
     selections.Sort((sortcomparefunc)&myCompareInts);
     for (int i=numSelected-1; i>=0; --i) {
         m_exclusiveGPUApsListBox->Delete(selections[i]);
         m_bExclusiveAppsDataChanged = true;
     }
+    // Check if no more exclusive GPU apps exist.  If no more, disable remove button.
+    if (!m_exclusiveGPUApsListBox->HasClientObjectData()) {
+        m_removeExclusiveGPUAppButton->Disable();
+    }
     ev.Skip();
 }
 
 // handles OK button clicked
 void CDlgExclusiveApps::OnOK(wxCommandEvent& ev) {
     SavePreferencesSettings();
-    
+
     ev.Skip();
 }
 
