@@ -132,13 +132,6 @@ int COPROC::parse(XML_PARSER& xp) {
     while (!xp.get_tag()) {
         if (!xp.is_tag) continue;
         if (xp.match_tag("/coproc")) {
-            // The client reports the type of Apple GPUs as the model
-            // (e.g. "Apple M1").
-            // Change it to just "Apple".
-            //
-            if (strstr(type, "Apple")) {
-                strcpy(type, "Apple");
-            }
             if (!strlen(type)) return ERR_XML_PARSE;
             clear_usage();
             return 0;
@@ -202,8 +195,18 @@ void COPROCS::summary_string(char* buf, int len) {
         );
         strlcat(buf, buf2, len);
     }
+    if (apple_gpu.count) {
+        snprintf(buf2, sizeof(buf2),
+            "[apple_gpu|%s|%d|%dMB|%d|%d]",
+            apple_gpu.model, apple_gpu.count,
+            (int)(apple_gpu.opencl_prop.global_mem_size/MEGA),
+            apple_gpu.metal_support,
+            apple_gpu.opencl_prop.opencl_device_version_int
+        );
+        strlcat(buf, buf2, len);
+    }
 
-    // add OpenCL devices other than nvidia/amd/intel
+    // add OpenCL devices other than nvidia/amd/intel/apple
     //
     for (int i=1; i<n_rsc; i++) {
         COPROC& cp = coprocs[i];
@@ -260,6 +263,15 @@ int COPROCS::parse(XML_PARSER& xp) {
             }
             continue;
         }
+        if (xp.match_tag("coproc_apple_gpu")) {
+            retval = apple_gpu.parse(xp);
+            if (retval) {
+                apple_gpu.clear();
+            } else {
+                coprocs[n_rsc++] = apple_gpu;
+            }
+            continue;
+        }
         if (xp.match_tag("coproc")) {
             COPROC cp;
             retval = cp.parse(xp);
@@ -291,6 +303,9 @@ void COPROCS::write_xml(MIOFILE& mf, bool scheduler_rpc) {
         case PROC_TYPE_INTEL_GPU:
             intel_gpu.write_xml(mf, scheduler_rpc);
             break;
+        case PROC_TYPE_APPLE_GPU:
+            apple_gpu.write_xml(mf, scheduler_rpc);
+            break;
         default:
             coprocs[i].write_xml(mf, scheduler_rpc);
         }
@@ -935,7 +950,6 @@ void COPROC_INTEL::clear() {
     estimated_delay = -1;
     safe_strcpy(name, "");
     safe_strcpy(version, "");
-    global_mem_size = 0;
     is_used = COPROC_USED;
 }
 
@@ -1003,6 +1017,108 @@ void COPROC_INTEL::fake(double ram, double avail_ram, int n) {
     opencl_prop.global_mem_size = (cl_ulong)ram;
 }
 
+////////////////// APPLE GPU STARTS HERE /////////////////
+
+#ifndef _USING_FCGI_
+void COPROC_APPLE::write_xml(MIOFILE& f, bool scheduler_rpc) {
+    f.printf(
+        "<coproc_apple_gpu>\n"
+        "   <count>%d</count>\n"
+        "   <model>%s</model>\n"
+        "   <available_ram>%f</available_ram>\n"
+        "   <have_metal>%d</have_metal>\n"
+        "   <have_opencl>%d</have_opencl>\n"
+        "   <ncores>%d</ncores>\n"
+        "   <metal_support>%d</metal_support>\n",
+        count,
+        model,
+        available_ram,
+        have_metal ? 1 : 0,
+        have_opencl ? 1 : 0,
+        ncores,
+        metal_support
+    );
+    if (scheduler_rpc) {
+        write_request(f);
+    }
+    f.printf(
+        "   <peak_flops>%f</peak_flops>\n",
+        peak_flops
+    );
+
+    if (have_opencl) {
+        opencl_prop.write_xml(f, "coproc_opencl");
+    }
+
+    f.printf("</coproc_apple_gpu>\n");
+}
+#endif
+
+void COPROC_APPLE::clear() {
+    static const COPROC_APPLE x(0);
+    *this = x;
+    safe_strcpy(type, proc_type_name_xml(PROC_TYPE_APPLE_GPU));
+    estimated_delay = -1;
+    is_used = COPROC_USED;
+}
+
+int COPROC_APPLE::parse(XML_PARSER& xp) {
+    int retval;
+
+    clear();
+    while (!xp.get_tag()) {
+        if (xp.match_tag("/coproc_apple_gpu")) {
+            if (!peak_flops) {
+				set_peak_flops();
+            }
+            if (!available_ram) {
+                available_ram = opencl_prop.global_mem_size;
+            }
+            return 0;
+        }
+        if (xp.parse_int("count", count)) continue;
+        if (xp.parse_str("model", model, sizeof(model))) continue;
+        if (xp.parse_double("peak_flops", peak_flops)) continue;
+        if (xp.parse_bool("have_opencl", have_opencl)) continue;
+        if (xp.parse_bool("have_metal", have_metal)) continue;
+        if (xp.parse_double("available_ram", available_ram)) continue;
+        if (xp.parse_int("ncores", ncores)) continue;
+        if (xp.parse_int("metal_support", metal_support)) continue;
+        if (xp.parse_double("req_secs", req_secs)) continue;
+        if (xp.parse_double("req_instances", req_instances)) continue;
+        if (xp.parse_double("estimated_delay", estimated_delay)) continue;
+
+        if (xp.match_tag("coproc_opencl")) {
+            retval = opencl_prop.parse(xp, "/coproc_opencl");
+            if (retval) return retval;
+            continue;
+        }
+    }
+    return ERR_XML_PARSE;
+}
+
+void COPROC_APPLE::set_peak_flops() {
+    if (opencl_prop.max_compute_units) {
+        peak_flops = opencl_prop.max_compute_units * 8 * opencl_prop.max_clock_frequency * 1e6;
+    } else {
+        peak_flops = 1e11;    // default 100 GFLOPS
+    }
+}
+
+void COPROC_APPLE::fake(double ram, double avail_ram, int n) {
+    safe_strcpy(type, proc_type_name_xml(PROC_TYPE_APPLE_GPU));
+    count = n;
+    available_ram = avail_ram;
+    have_opencl = true;
+    for (int i=0; i<count; i++) {
+        device_nums[i] = i;
+    }
+    set_peak_flops();
+    opencl_prop.global_mem_size = (cl_ulong)ram;
+}
+
+///////////////////// END GPU TYPES ///////////////
+
 // used wherever a processor type is specified in XML, e.g.
 // <coproc>
 //    <type>xxx</type>
@@ -1012,6 +1128,7 @@ void COPROC_INTEL::fake(double ram, double avail_ram, int n) {
 // coproc_cuda
 // coproc_ati
 // coproc_intel_gpu
+// coproc_apple_gpu
 //
 const char* proc_type_name_xml(int pt) {
     switch(pt) {
@@ -1019,7 +1136,7 @@ const char* proc_type_name_xml(int pt) {
     case PROC_TYPE_NVIDIA_GPU: return "NVIDIA";
     case PROC_TYPE_AMD_GPU: return "ATI";
     case PROC_TYPE_INTEL_GPU: return "intel_gpu";
-    case PROC_TYPE_MINER_ASIC: return "miner_asic";
+    case PROC_TYPE_APPLE_GPU: return "apple_gpu";
     }
     return "unknown";
 }
@@ -1030,7 +1147,7 @@ const char* proc_type_name(int pt) {
     case PROC_TYPE_NVIDIA_GPU: return "NVIDIA GPU";
     case PROC_TYPE_AMD_GPU: return "AMD/ATI GPU";
     case PROC_TYPE_INTEL_GPU: return "Intel GPU";
-    case PROC_TYPE_MINER_ASIC: return "Miner ASIC";
+    case PROC_TYPE_APPLE_GPU: return "Apple GPU";
     }
     return "unknown";
 }
@@ -1040,6 +1157,6 @@ int coproc_type_name_to_num(const char* name) {
     if (!strcmp(name, "NVIDIA")) return PROC_TYPE_NVIDIA_GPU;
     if (!strcmp(name, "ATI")) return PROC_TYPE_AMD_GPU;
     if (!strcmp(name, "intel_gpu")) return PROC_TYPE_INTEL_GPU;
-    if (!strcmp(name, "miner_asic")) return PROC_TYPE_MINER_ASIC;
+    if (!strcmp(name, "apple_gpu")) return PROC_TYPE_APPLE_GPU;
     return -1;      // Some other type
 }
