@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2018 University of California
+// Copyright (C) 2023 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -39,10 +39,12 @@
 #endif
 #endif
 
-#ifdef _USING_FCGI_
-#include "boinc_fcgi.h"
+#ifdef __APPLE__
+#include <xlocale.h>
 #endif
 
+#include "boinc_stdio.h"
+
 #include "error_numbers.h"
 #include "str_replace.h"
 #include "str_util.h"
@@ -52,6 +54,28 @@
 
 using std::string;
 
+unsigned long long boinc_strtoull(const char *str, char **endptr, int base) {
+#if (defined (__cplusplus) && __cplusplus > 199711L) || defined(HAVE_STRTOULL) || defined(__MINGW32__)
+    return strtoull(str, endptr, base);
+#elif defined(_WIN32) && !defined(__MINGW32__)
+    return _strtoui64(str, endptr, base);
+#else
+    char buf[64];
+    char *p;
+    unsigned long long y;
+    strncpy(buf, str, sizeof(buf)-1);
+    strip_whitespace(buf);
+    p = strstr(buf, "0x");
+    if (!p) p = strstr(buf, "0X");
+    if (p) {
+        sscanf(p, "%llx", &y);
+    } else {
+        sscanf(buf, "%llu", &y);
+    }
+    return y;
+#endif
+}
+
 // Parse a boolean; tag is of form "foobar"
 // Accept either <foobar/>, <foobar />, or <foobar>0|1</foobar>
 // (possibly with leading/trailing white space)
@@ -133,10 +157,10 @@ void parse_attr(const char* buf, const char* name, char* dest, int len) {
 
 int copy_stream(FILE* in, FILE* out) {
     char buf[1024];
-    int n, m;
+    size_t n, m;
     while (1) {
-        n = (int)fread(buf, 1, 1024, in);
-        m = (int)fwrite(buf, 1, n, out);
+        n = boinc::fread(buf, 1, 1024, in);
+        m = boinc::fwrite(buf, 1, n, out);
         if (m != n) return ERR_FWRITE;
         if (n < 1024) break;
     }
@@ -204,7 +228,7 @@ int copy_element_contents(FILE* in, const char* end_tag, string& str) {
 
     str = "";
     while (1) {
-        c = fgetc(in);
+        c = boinc::fgetc(in);
         if (c == EOF) break;
         str += c;
         n++;
@@ -723,7 +747,12 @@ bool XML_PARSER::parse_double(const char* start_tag, double& x) {
         }
     }
     errno = 0;
+#if (defined(__APPLE__) && defined(BUILDING_MANAGER))
+// MacOS 13.3.1 apparently broke per-thread locale uselocale()
+    double val = strtod_l(buf, &end, LC_C_LOCALE);
+#else
     double val = strtod(buf, &end);
+#endif
     if (errno) return false;
     if (end != buf+strlen(buf)) return false;
 
@@ -873,7 +902,7 @@ void XML_PARSER::skip_unexpected(
     char buf[TAG_BUF_LEN], end_tag[TAG_BUF_LEN];
 
     if (verbose) {
-        fprintf(stderr,
+        boinc::fprintf(stderr,
             "%s: Unrecognized XML tag '<%s>' in %s; skipping\n",
             time_to_string(dtime()), start_tag, where
         );
