@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// Copyright (C) 2023 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -25,10 +25,7 @@
 #include <time.h>
 #endif
 
-#ifdef _USING_FCGI_
-#include "boinc_fcgi.h"
-#endif
-
+#include "boinc_stdio.h"
 #include "error_numbers.h"
 #include "str_replace.h"
 #include "parse.h"
@@ -60,6 +57,9 @@ void GLOBAL_PREFS_MASK::set_all() {
     net_end_hour = true;
     net_start_hour = true;
     network_wifi_only = true;
+    niu_max_ncpus_pct = true;
+    niu_cpu_usage_limit = true;
+    niu_suspend_cpu_usage = true;
     ram_max_used_busy_frac = true;
     ram_max_used_idle_frac = true;
     run_gpu_if_user_active = true;
@@ -97,6 +97,9 @@ bool GLOBAL_PREFS_MASK::are_prefs_set() {
     if (net_start_hour) return true;
     if (network_wifi_only) return true;
     if (net_end_hour) return true;
+    if (niu_max_ncpus_pct) return true;
+    if (niu_cpu_usage_limit) return true;
+    if (niu_suspend_cpu_usage) return true;
     if (ram_max_used_busy_frac) return true;
     if (ram_max_used_idle_frac) return true;
     if (run_gpu_if_user_active) return true;
@@ -232,6 +235,9 @@ void GLOBAL_PREFS::defaults() {
 #else
     network_wifi_only = false;
 #endif
+    niu_max_ncpus_pct = 100;
+    niu_cpu_usage_limit = 100;
+    niu_suspend_cpu_usage = 50;
     ram_max_used_busy_frac = 0.5;
 #ifdef ANDROID
     ram_max_used_idle_frac = 0.5;
@@ -250,7 +256,7 @@ void GLOBAL_PREFS::defaults() {
     vm_max_used_frac = 0.75;
     work_buf_additional_days = 0.5;
     work_buf_min_days = 0.1;
-    
+
     override_file_present = false;
 
     // don't initialize source_project, source_scheduler,
@@ -266,6 +272,7 @@ void GLOBAL_PREFS::defaults() {
 //
 void GLOBAL_PREFS::enabled_defaults() {
     defaults();
+    suspend_if_no_recent_input = 60;
     disk_max_used_gb = 100;
     disk_min_free_gb = 1.0;
     daily_xfer_limit_mb = 10000;
@@ -388,6 +395,17 @@ int GLOBAL_PREFS::parse_override(
             if (net_times.start_hour == net_times.end_hour) {
                 mask.net_start_hour = mask.net_end_hour = false;
             }
+            // if not-in-use prefs weren't specified, use in-use counterpart
+            //
+            if (!mask.niu_max_ncpus_pct) {
+                niu_max_ncpus_pct = max_ncpus_pct;
+            }
+            if (!mask.niu_cpu_usage_limit) {
+                niu_cpu_usage_limit = cpu_usage_limit;
+            }
+            if (!mask.niu_suspend_cpu_usage) {
+                niu_suspend_cpu_usage = suspend_cpu_usage;
+            }
             return 0;
         }
         if (in_venue) {
@@ -460,6 +478,10 @@ int GLOBAL_PREFS::parse_override(
             mask.suspend_cpu_usage = true;
             continue;
         }
+        if (xp.parse_double("niu_suspend_cpu_usage", niu_suspend_cpu_usage)) {
+            mask.niu_suspend_cpu_usage = true;
+            continue;
+        }
         if (xp.parse_double("start_hour", cpu_times.start_hour)) {
             mask.start_hour = true;
             continue;
@@ -512,6 +534,12 @@ int GLOBAL_PREFS::parse_override(
             mask.max_ncpus_pct = true;
             continue;
         }
+        if (xp.parse_double("niu_max_ncpus_pct", niu_max_ncpus_pct)) {
+            if (niu_max_ncpus_pct <= 0) niu_max_ncpus_pct = 100;
+            if (niu_max_ncpus_pct > 100) niu_max_ncpus_pct = 100;
+            mask.niu_max_ncpus_pct = true;
+            continue;
+        }
         if (xp.parse_int("max_cpus", max_ncpus)) {
             if (max_ncpus < 0) max_ncpus = 0;
             mask.max_ncpus = true;
@@ -573,6 +601,13 @@ int GLOBAL_PREFS::parse_override(
             }
             continue;
         }
+        if (xp.parse_double("niu_cpu_usage_limit", dtemp)) {
+            if (dtemp <= 0) dtemp = 100;
+            if (dtemp > 100) dtemp = 100;
+            niu_cpu_usage_limit = dtemp;
+            mask.niu_cpu_usage_limit = true;
+            continue;
+        }
         if (xp.parse_double("daily_xfer_limit_mb", dtemp)) {
             if (dtemp >= 0) {
                 daily_xfer_limit_mb = dtemp;
@@ -652,6 +687,9 @@ int GLOBAL_PREFS::write(MIOFILE& f) {
         "   <work_buf_min_days>%f</work_buf_min_days>\n"
         "   <work_buf_additional_days>%f</work_buf_additional_days>\n"
         "   <max_ncpus_pct>%f</max_ncpus_pct>\n"
+        "   <niu_max_ncpus_pct>%f</niu_max_ncpus_pct>\n"
+        "   <niu_cpu_usage_limit>%f</niu_cpu_usage_limit>\n"
+        "   <niu_suspend_cpu_usage>%f</niu_suspend_cpu_usage>\n"
         "   <cpu_scheduling_period_minutes>%f</cpu_scheduling_period_minutes>\n"
         "   <disk_interval>%f</disk_interval>\n"
         "   <disk_max_used_gb>%f</disk_max_used_gb>\n"
@@ -688,6 +726,9 @@ int GLOBAL_PREFS::write(MIOFILE& f) {
         work_buf_min_days,
         work_buf_additional_days,
         max_ncpus_pct,
+        niu_max_ncpus_pct,
+        niu_cpu_usage_limit,
+        niu_suspend_cpu_usage,
         cpu_scheduling_period_minutes,
         disk_interval,
         disk_max_used_gb,
@@ -722,8 +763,8 @@ void GLOBAL_PREFS::write_day_prefs(MIOFILE& f) {
         bool net_present = net_times.week.days[i].present;
         //write only when needed
         if (net_present || cpu_present) {
-            
-            f.printf("   <day_prefs>\n");                
+
+            f.printf("   <day_prefs>\n");
             f.printf("      <day_of_week>%d</day_of_week>\n", i);
             if (cpu_present) {
                 f.printf(
@@ -751,7 +792,7 @@ void GLOBAL_PREFS::write_day_prefs(MIOFILE& f) {
 //
 int GLOBAL_PREFS::write_subset(MIOFILE& f, GLOBAL_PREFS_MASK& mask) {
     if (!mask.are_prefs_set()) return 0;
-    
+
     f.printf("<global_preferences>\n");
     if (mask.run_on_batteries) {
         f.printf("   <run_on_batteries>%d</run_on_batteries>\n",
@@ -778,7 +819,6 @@ int GLOBAL_PREFS::write_subset(MIOFILE& f, GLOBAL_PREFS_MASK& mask) {
         );
     }
     if (mask.suspend_cpu_usage) {
-
         f.printf("   <suspend_cpu_usage>%f</suspend_cpu_usage>\n",
             suspend_cpu_usage
         );
@@ -834,6 +874,17 @@ int GLOBAL_PREFS::write_subset(MIOFILE& f, GLOBAL_PREFS_MASK& mask) {
     if (mask.max_ncpus_pct) {
         f.printf("   <max_ncpus_pct>%f</max_ncpus_pct>\n", max_ncpus_pct);
     }
+    if (mask.niu_max_ncpus_pct) {
+        f.printf("   <niu_max_ncpus_pct>%f</niu_max_ncpus_pct>\n", niu_max_ncpus_pct);
+    }
+    if (mask.niu_cpu_usage_limit) {
+        f.printf("   <niu_cpu_usage_limit>%f</niu_cpu_usage_limit>\n", niu_cpu_usage_limit);
+    }
+    if (mask.niu_suspend_cpu_usage) {
+        f.printf("   <niu_suspend_cpu_usage>%f</niu_suspend_cpu_usage>\n",
+            niu_suspend_cpu_usage
+        );
+    }
     if (mask.max_ncpus) {
         f.printf("   <max_cpus>%d</max_cpus>\n", max_ncpus);
     }
@@ -885,3 +936,10 @@ int GLOBAL_PREFS::write_subset(MIOFILE& f, GLOBAL_PREFS_MASK& mask) {
     return 0;
 }
 
+// parse the <mod_time> element from a prefs XML string
+//
+double GLOBAL_PREFS::parse_mod_time(const char* p) {
+    const char *q = strstr(p, "<mod_time>");
+    if (!q) return 0;
+    return atof(q+strlen("<mod_time>"));
+}
