@@ -234,7 +234,7 @@ void kill_descendants(int child_pid) {
             if (!any_process_exists(descendants)) {
                 return;
             }
-            sleep(1);
+            boinc_sleep(1);
         }
         kill_all(descendants);
         // kill any processes that might have been created
@@ -245,35 +245,45 @@ void kill_descendants(int child_pid) {
 }
 #endif
 
-// suspend/resume the descendants of the calling process
-// (or if pid==0, the calling process)
+// suspend/resume the descendants of the calling process.
+// Unix version lets you choose the stop signal:
+// SIGSTOP (the default) can't be caught.
+// SIGTSTP can be caught, but it has no effect for processes without a TTY.
+// So it's useful only for programs that are wrappers of some sort;
+// they must catch and handle it.
 //
+#ifdef _WIN32
 void suspend_or_resume_descendants(bool resume) {
     vector<int> descendants;
-#ifdef _WIN32
     int pid = GetCurrentProcessId();
     get_descendants(pid, descendants);
     suspend_or_resume_threads(descendants, 0, resume, false);
+}
 #else
+void suspend_or_resume_descendants(bool resume, bool use_tstp) {
+    vector<int> descendants;
     int pid = getpid();
     get_descendants(pid, descendants);
     for (unsigned int i=0; i<descendants.size(); i++) {
-        kill(descendants[i], resume?SIGCONT:SIGTSTP);
+        kill(descendants[i], resume?SIGCONT:(use_tstp?SIGTSTP:SIGSTOP));
     }
-#endif
 }
+#endif
 
-// used by the wrapper
+// Suspend/resume the given process; used by the wrapper.
+// See signal comment above.
 //
-void suspend_or_resume_process(int pid, bool resume) {
 #ifdef _WIN32
+void suspend_or_resume_process(int pid, bool resume) {
     vector<int> pids;
     pids.push_back(pid);
     suspend_or_resume_threads(pids, 0, resume, false);
-#else
-    ::kill(pid, resume?SIGCONT:SIGTSTP);
-#endif
 }
+#else
+void suspend_or_resume_process(int pid, bool resume, bool use_tstp) {
+    ::kill(pid, resume?SIGCONT:(use_tstp?SIGTSTP:SIGSTOP));
+}
+#endif
 
 // return OS-specific value associated with priority code
 //
