@@ -20,12 +20,13 @@
 //
 // Currently this is specific to Einstein@home and is not generally usable.
 // There's a generic but more limited version, "limited locality scheduling":
-// http://boinc.berkeley.edu/trac/wiki/LocalityScheduling
+// https://github.com/BOINC/boinc/wiki/LocalityScheduling
 
 #include "config.h"
 
 #include <algorithm>
 #include <climits>
+#include <ctime>
 #include <vector>
 
 #include <cstdio>
