@@ -217,6 +217,9 @@ void PROJECT_PREFS::parse() {
     if (parse_bool(buf,"no_intel_gpu", flag)) {
         dont_use_proc_type[PROC_TYPE_INTEL_GPU] = flag;
     }
+    if (parse_bool(buf,"no_apple_gpu", flag)) {
+        dont_use_proc_type[PROC_TYPE_APPLE_GPU] = flag;
+    }
     if (parse_int(buf, "<max_cpus>", temp_int)) {
         max_cpus = temp_int;
     }
@@ -1027,6 +1030,10 @@ int SCHEDULER_REPLY::write(FILE* fout, SCHEDULER_REQUEST& sreq) {
         boinc::fprintf(fout, "<non_cpu_intensive/>\n");
     }
 
+    if (config.strict_memory_bound) {
+        boinc::fprintf(fout, "<strict_memory_bound/>\n");
+    }
+
     if (config.verify_files_on_app_start) {
         boinc::fprintf(fout, "<verify_files_on_app_start/>\n");
     }
